@@ -4,5 +4,6 @@ variables in the dataframe.
 """
 
 from .mathematical_combination import MathematicalCombination
+from .combine_with_reference_feature import CombineWithReferenceFeature
 
-__all__ = ["MathematicalCombination"]
+__all__ = ["MathematicalCombination", "CombineWithReferenceFeature"]
